@@ -27,16 +27,20 @@ impl Move {
 
         if s.contains("_") {
             let mut fen_parts = s.split("_");
-
-            if let Some(from) = Square::from_sfen(fen_parts.next().unwrap()) {
-                if let Some(to) = Square::from_sfen(fen_parts.next().unwrap()) {
-                    return Some(Move::Normal {
-                        from,
-                        to,
-                        promote: false,
-                    });
+            if let Some(from) = fen_parts.next() {
+                if let Some(from) = Square::from_sfen(from) {
+                    if let Some(to) = fen_parts.next() {
+                        if let Some(to) = Square::from_sfen(to) {
+                            return Some(Move::Normal {
+                                from,
+                                to,
+                                promote: false,
+                            });
+                        }
+                    }
                 }
             }
+
             return None;
         } else {
             let buy_move = Move::get_buy_move(&s);
@@ -51,6 +55,7 @@ impl Move {
         }
     }
 
+    /// Information about normal move.
     pub fn info(&self) -> (Square, Square) {
         match self {
             Move::Normal {
@@ -65,10 +70,12 @@ impl Move {
         }
     }
 
+    /// Creating new normal with 'from' and 'to' Square.
     pub fn new(from: Square, to: Square, promote: bool) -> Move {
         Move::Normal { from, to, promote }
     }
 
+    /// Getting buy move from str.
     pub fn get_buy_move(s: &str) -> Option<Move> {
         if s.len() == 2 {
             if s.chars().nth(0).unwrap() == '+' {
@@ -80,11 +87,18 @@ impl Move {
         None
     }
 
+    /// Getting put move from str.
     pub fn get_put_move(s: &str) -> Option<Move> {
         let mut fen_parts = s.split("@");
-        if let Some(piece) = Piece::from_sfen(fen_parts.next().unwrap().chars().next().unwrap()) {
-            if let Some(to) = Square::from_sfen(fen_parts.next().unwrap()) {
-                return Some(Move::Put { piece, to });
+        if let Some(piece_str) = fen_parts.next() {
+            if let Some(piece_char) = piece_str.chars().next() {
+                if let Some(piece) = Piece::from_sfen(piece_char) {
+                    if let Some(to) = fen_parts.next() {
+                        if let Some(to) = Square::from_sfen(to) {
+                            return Some(Move::Put { piece, to });
+                        }
+                    }
+                }
             }
         }
         return None;
@@ -174,7 +188,7 @@ impl PartialEq<Move> for MoveRecord {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::square::consts::*;
+    use crate::{square::consts::*, Color, PieceType};
 
     #[test]
     fn from_sfen() {
@@ -211,6 +225,79 @@ mod tests {
             assert_eq!(case.1, m.unwrap(), "failed at #{}", i);
         }
     }
+
+    #[test]
+    fn from_sfen_buy() {
+        let ok_cases = [
+            (
+                "+n",
+                Piece {
+                    piece_type: PieceType::Knight,
+                    color: Color::Black,
+                },
+            ),
+            (
+                "+P",
+                Piece {
+                    piece_type: PieceType::Pawn,
+                    color: Color::White,
+                },
+            ),
+            (
+                "+r",
+                Piece {
+                    piece_type: PieceType::Rook,
+                    color: Color::Black,
+                },
+            ),
+        ];
+        for (i, case) in ok_cases.iter().enumerate() {
+            let m = Move::from_sfen(case.0);
+            assert!(m.is_some(), "failed at #{}", i);
+            assert_eq!(Move::Buy { piece: case.1 }, m.unwrap(), "failed at #{}", i);
+        }
+
+        let ng_cases = ["++", "+1", "+@", "+NN", "+LL", "+*"];
+
+        for (i, case) in ng_cases.iter().enumerate() {
+            let m = Move::from_sfen(case);
+            assert!(m.is_none(), "failed at #{}", i);
+        }
+    }
+
+    #[test]
+    fn from_sfen_place() {
+        let ok_cases = [
+            ("R@b1", PieceType::Rook, Color::White, B1, false),
+            ("n@d12", PieceType::Knight, Color::Black, D12, false),
+            ("P@g3", PieceType::Pawn, Color::White, G3, false),
+        ];
+
+        for (i, case) in ok_cases.iter().enumerate() {
+            let m = Move::from_sfen(case.0);
+            assert!(!m.is_none(), "failed at #{}", i);
+            assert_eq!(
+                Move::Put {
+                    to: case.3,
+                    piece: Piece {
+                        piece_type: case.1,
+                        color: case.2
+                    }
+                },
+                m.unwrap(),
+                "failed at #{}",
+                i
+            );
+        }
+
+        let ng_cases = [("S@b4", B4), ("V@b4", B4), ("s@b55", J12)];
+
+        for (i, case) in ng_cases.iter().enumerate() {
+            let m = Move::from_sfen(case.0);
+            assert!(!m.is_some(), "failed at #{}", i);
+        }
+    }
+
     #[test]
     fn to_sfen() {
         let cases = [
