@@ -1210,10 +1210,11 @@ impl Position {
             return EMPTY_BB;
         }
         let mut all;
+        let occupied_bb = &self.occupied_bb | self.player_bb(Color::NoColor);
         for p in [PieceType::Queen, PieceType::Rook, PieceType::Bishop] {
             let bb = &self.type_bb[p.index()] & &self.color_bb[attacked_color.flip().index()];
             for i in bb {
-                all = get_sliding_attacks(p, i, self.occupied_bb);
+                all = get_sliding_attacks(p, i, occupied_bb);
                 if (&all & &king).is_any() {
                     match *attacked_color {
                         Color::White => {
@@ -2020,4 +2021,32 @@ pub mod tests {
         }
         assert_eq!(position_set.get_hand(Color::Black), "rrbn");
     }
+
+    #[test]
+    fn empty_squares_with_plinths() {
+        setup();
+        let cases = [
+            (
+                "5K1Q4/L056/5L05L0/57/57/7L04/57/2L09/57/8L03/4L02L04/7k4 b q2rb4n3pQ2R3BN3P 3",
+                11,
+                Color::Black,
+            ),
+            (
+                "4LN2K4/5L06/9L02/57/55L01/57/57/57/1L01L02L05/57/57/6kq3L0 w rnQNRBP 4",
+                2,
+                Color::White,
+            ),
+        ];
+        for case in cases {
+            let mut position_set = Position::default();
+            position_set
+                .set_sfen(case.0)
+                .expect("error while parsing sfen");
+            let file = position_set.empty_squares(Piece {
+                piece_type: PieceType::Knight,
+                color: case.2,
+            });
+            assert_eq!(file.count(), case.1);
+        }
+    }
 }
